==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PolarSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarSplineAreaSeriesDescription } from "./PolarSplineAreaSeriesDescription";
/**
 * @hidden
 */
var PolarSplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarSplineAreaSeriesDescriptionMetadata, _super);
    function PolarSplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarSplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (PolarSplineAreaSeriesDescriptionMetadata.a == null) {
            PolarSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarSplineAreaSeriesDescriptionMetadata.c(PolarSplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.g(PolarSplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(PolarSplineAreaSeriesDescriptionMetadata.a);
    };
    PolarSplineAreaSeriesDescriptionMetadata.c = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.c(a);
        a.item("Stiffness", "Number:double");
    };
    PolarSplineAreaSeriesDescriptionMetadata.d = function (a) {
        PolarSplineAreaSeriesDescriptionMetadata.b(a);
        a.u("PolarSplineAreaSeries", function () { return new PolarSplineAreaSeriesDescription(); });
        a.t("PolarSplineAreaSeries", PolarSplineAreaSeriesDescriptionMetadata.a);
    };
    PolarSplineAreaSeriesDescriptionMetadata.$t = markType(PolarSplineAreaSeriesDescriptionMetadata, 'PolarSplineAreaSeriesDescriptionMetadata');
    PolarSplineAreaSeriesDescriptionMetadata.a = null;
    return PolarSplineAreaSeriesDescriptionMetadata;
}(Base));
export { PolarSplineAreaSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PolarSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarSplineAreaSeriesDescription } from "./PolarSplineAreaSeriesDescription";
/**
 * @hidden
 */
var PolarSplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarSplineAreaSeriesDescriptionMetadata, _super);
    function PolarSplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarSplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (PolarSplineAreaSeriesDescriptionMetadata.a == null) {
            PolarSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarSplineAreaSeriesDescriptionMetadata.c(PolarSplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.j(PolarSplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(PolarSplineAreaSeriesDescriptionMetadata.a);
    };
    PolarSplineAreaSeriesDescriptionMetadata.c = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.c(a);
        a.item("Stiffness", "Number:double");
    };
    PolarSplineAreaSeriesDescriptionMetadata.d = function (a) {
        PolarSplineAreaSeriesDescriptionMetadata.b(a);
        a.aa("PolarSplineAreaSeries", function () { return new PolarSplineAreaSeriesDescription(); });
        a.z("PolarSplineAreaSeries", PolarSplineAreaSeriesDescriptionMetadata.a);
    };
    PolarSplineAreaSeriesDescriptionMetadata.$t = markType(PolarSplineAreaSeriesDescriptionMetadata, 'PolarSplineAreaSeriesDescriptionMetadata');
    PolarSplineAreaSeriesDescriptionMetadata.a = null;
    return PolarSplineAreaSeriesDescriptionMetadata;
}(Base));
export { PolarSplineAreaSeriesDescriptionMetadata };
